==> 0.0.50.tar.gz: lib/CustomAlertComponent/CustomeAlert.dart <==
/*
    Refer License for Terms & Conditions
 */
library bui_component;

import 'package:flutter/material.dart';
import 'package:bui_component/Constants/AppColors.dart';
import 'package:bui_component/Constants/fontSize.dart';

class CustomAlertBox {
  static Future showCustomAlertBox({
    @required BuildContext context,
    @required Widget enterWidget,
    @required String type,
    @required bool isPositiveEnabled,
    @required bool isNegativeEnabled = false,
    Color positiveButtonColor,
    Color positiveButtonTextColor,
    @required Function() setPositiveAction,
  }) {
    assert(context != null, "context is null!!");
    assert(type != null, "Type is null!!");
    assert(enterWidget != null, "willDisplayWidget is null!!");

    return showDialog(
        context: context,
        builder: (context) {
          return AlertDialog(
            title: Text(
              type ?? 'Warning!!',
              textAlign: TextAlign.center,
              style: TextStyle(
                  fontWeight: FontWeight.w900,
                  fontSize: FontSize.FONT_20,
                  color: AppColors.APP_COLOR_BLACK),
            ),
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.all(Radius.circular(15)),
            ),
            backgroundColor: Colors.white,
            content: Column(mainAxisSize: MainAxisSize.min, children: <Widget>[
              enterWidget,
              SizedBox(
                height: 20,
              ),
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  isNegativeEnabled
                      ? MaterialButton(
                          color: AppColors.APP_COLOR_WHITE,
                          shape: RoundedRectangleBorder(
                              borderRadius: BorderRadius.circular(5.0)),
                          elevation: 1.0,
                          clipBehavior: Clip.antiAlias,
                          child: Text(
                            'Cancel',
                            style: TextStyle(
                                //fontWeight: FontWeight.w700,
                                fontSize: FontSize.FONT_16,
                                color: Colors.black),
                          ),
                          onPressed: () {
                            Navigator.of(context).pop();
                          },
                        )
                      : Container(),
                  isNegativeEnabled
                      ? SizedBox(
                          width: 30,
                        )
                      : Container(),
                  isPositiveEnabled
                      ? MaterialButton(
                          color: positiveButtonColor ?? AppColors.errorWarning,
                          shape: RoundedRectangleBorder(
                              borderRadius: BorderRadius.circular(5.0)),
                          elevation: 30.0,
                          clipBehavior: Clip.antiAlias,
                          child: Text(
                            'Okay',
                            style: TextStyle(
                              //   fontWeight: FontWeight.w700,
                              fontSize: FontSize.FONT_16,
                              color: positiveButtonTextColor ?? Colors.white,
                            ),
                          ),
                          onPressed: () {
                            setPositiveAction();
                            Navigator.of(context).pop();
                          },
                        )
                      : MaterialButton(
                          color: positiveButtonColor ?? AppColors.errorWarning,
                          shape: RoundedRectangleBorder(
                              borderRadius: BorderRadius.circular(5.0)),
                          elevation: 30.0,
                          clipBehavior: Clip.antiAlias,
                          child: Text(
                            'Okay',
                            style: TextStyle(
                              //   fontWeight: FontWeight.w700,
                              fontSize: FontSize.FONT_16,
                              color: positiveButtonTextColor ?? Colors.white,
                            ),
                          ),
                          onPressed: () {
                            setPositiveAction();
                            Navigator.of(context).pop();
                          },
                        ),
                ],
              ),
            ]),
            elevation: 1,
          );
        });
  }
}

==> 0.0.63.tar.gz: lib/CustomAlertComponent/CustomeAlert.dart <==
/*
    Refer License for Terms & Conditions
 */
library bui_component;

import 'package:flutter/material.dart';
import 'package:bui_component/Constants/AppColors.dart';
import 'package:bui_component/Constants/fontSize.dart';

class CustomAlertBox {
  static Future showCustomAlertBox({
     BuildContext context,
     Widget enterWidget,
     String type,
     bool isPositiveEnabled,
     bool isNegativeEnabled = false,
    Color positiveButtonColor,
    Color positiveButtonTextColor,
     Function() setPositiveAction,
  }) {
    assert(context != null, "context is null!!");
    assert(type != null, "Type is null!!");
    assert(enterWidget != null, "willDisplayWidget is null!!");

    return showDialog(
        context: context,
        builder: (context) {
          return AlertDialog(
            title: Text(
              type ?? 'Warning!!',
              textAlign: TextAlign.center,
              style: TextStyle(
                  fontWeight: FontWeight.w900,
                  fontSize: FontSize.FONT_20,
                  color: AppColors.APP_COLOR_BLACK),
            ),
            shape: RoundedRectangleBorder(
              borderRadius: BorderRadius.all(Radius.circular(15)),
            ),
            backgroundColor: Colors.white,
            content: Column(mainAxisSize: MainAxisSize.min, children: <Widget>[
              enterWidget,
              SizedBox(
                height: 20,
              ),
              Row(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.center,
                children: [
                  isNegativeEnabled
                      ? MaterialButton(
                          color: AppColors.APP_COLOR_WHITE,
                          shape: RoundedRectangleBorder(
                              borderRadius: BorderRadius.circular(5.0)),
                          elevation: 1.0,
                          clipBehavior: Clip.antiAlias,
                          child: Text(
                            'Cancel',
                            style: TextStyle(
                                //fontWeight: FontWeight.w700,
                                fontSize: FontSize.FONT_16,
                                color: Colors.black),
                          ),
                          onPressed: () {
                            Navigator.of(context).pop();
                          },
                        )
                      : Container(),
                  isNegativeEnabled
                      ? SizedBox(
                          width: 30,
                        )
                      : Container(),
                  isPositiveEnabled
                      ? MaterialButton(
                          color: positiveButtonColor ?? AppColors.errorWarning,
                          shape: RoundedRectangleBorder(
                              borderRadius: BorderRadius.circular(5.0)),
                          elevation: 30.0,
                          clipBehavior: Clip.antiAlias,
                          child: Text(
                            'Okay',
                            style: TextStyle(
                              //   fontWeight: FontWeight.w700,
                              fontSize: FontSize.FONT_16,
                              color: positiveButtonTextColor ?? Colors.white,
                            ),
                          ),
                          onPressed: () {
                            setPositiveAction();
                            Navigator.of(context).pop();
                          },
                        )
                      : MaterialButton(
                          color: positiveButtonColor ?? AppColors.errorWarning,
                          shape: RoundedRectangleBorder(
                              borderRadius: BorderRadius.circular(5.0)),
                          elevation: 30.0,
                          clipBehavior: Clip.antiAlias,
                          child: Text(
                            'Okay',
                            style: TextStyle(
                              //   fontWeight: FontWeight.w700,
                              fontSize: FontSize.FONT_16,
                              color: positiveButtonTextColor ?? Colors.white,
                            ),
                          ),
                          onPressed: () {
                            setPositiveAction();
                            Navigator.of(context).pop();
                          },
                        ),
                ],
              ),
            ]),
            elevation: 1,
          );
        });
  }
}
